@@ -1,5 +1,5 @@
 service_headless = """[Unit]
-Description=LNXLink
+Description=LNXlink
 After=network-online.target
 
 [Service]
@@ -14,7 +14,7 @@ WantedBy=default.target
 """
 
 service_user = """[Unit]
-Description=LNXLink
+Description=LNXlink
 After=network-online.target multi-user.target graphical.target
 PartOf=graphical-session.target
  
@@ -48,25 +48,4 @@ mqtt:
     disconnectMsg: 'OFF'
 update_interval: 5
 modules:
-- bash
-- bluetooth_battery
-- cpu
-- disk_usage
-- idle
-- keep_alive
-- media
-- memory
-- microphone
-- network_download
-- network_upload
-- notify
-- nvidia_gpu
-- required_restart
-- restart
-- screen_onoff
-- send_keys
-- shutdown
-- suspend
-- update
-- xdg_open
 """
