@@ -9,13 +9,13 @@ class Addon():
 
     def exposedControls(self):
         return {
-            "Keep_Alive": {
+            "Keep Alive": {
                 "type": "switch",
                 "icon": "mdi:mouse-variant",
             }
         }
 
-    def getInfo(self):
+    def getControlInfo(self):
         if self.keepalive == 'ON':
             subprocess.run(
                 "xdotool key 0x00",
