@@ -2,10 +2,11 @@ import os
 
 
 class Addon():
-    name = 'Required Restart'
-    icon = 'mdi:alert-octagon-outline'
-    sensor_type = 'binary_sensor'
-    unit = ''
+
+    def __init__(self, lnxlink):
+        self.name = 'Required Restart'
+        self.sensor_type = 'binary_sensor'
+        self.icon = 'mdi:alert-octagon-outline'
 
     def getInfo(self):
         if os.path.exists('/var/run/reboot-required'):
