@@ -8,13 +8,13 @@ class Addon():
 
     def exposedControls(self):
         return {
-            "Screen_OnOff": {
+            "Screen OnOff": {
                 "type": "switch",
                 "icon": "mdi:monitor",
             }
         }
 
-    def getInfo(self):
+    def getControlInfo(self):
         stdout = subprocess.run(
             "xset q | grep -i 'monitor is'",
             shell=True,
